html {
    position: relative;
    min-height: 100%;
    font-size: 16px;
}
body {
    /* Margin bottom by footer height */
    margin-bottom: 60px;
    background-color: rgb(246, 248, 250);
}
img {
    padding: 2px;
}
a {
    color: #3572B0;
}

#sidebar {
    overflow: auto;
    max-height: 700px;
}

#sidebar .nav li {
  list-style-type: none;
  padding: 0;
  line-height: 1.0;
  flex-direction: row;
  flex-wrap: nowrap; /* assumes you only want one row */
}

.navbar-dark .navbar-nav .nav-link {
    color:
    rgb(255, 255, 255, 1);
}

.bg-guardian-blue {
    /* background-color: #0082c9; */
    background-image: linear-gradient(40deg, #0082c9 0%, #30b6ff 100%);
}
.btn-primary {
    background-color: #0082c9;
    opacity: 1;
    color: white;
}
.btn-secondary {
    background-color: #0082c9;
    opacity: 0.6;
    color: white;
}

.btn-outline-primary {
    border-color: #0082c9;
    color: #0082c9;
}

.bg-primary {
    background-color: #0082c9 !important;
    opacity: 1;
    color: white;
    text-align: center;
}

.badge-light {
    background-color: rgb(246, 248, 250);
    opacity: 1;
    color: #0082c9 !important;
}


/* Sticky footer */
.footer {
  position: absolute;
  bottom: 0;
  width: 100%;
  /* Set the fixed height of the footer here */
  height: 60px;
  line-height: 60px; /* Vertically center the text there */
  background-color: #006FBA;
}
.footer a{
    color: #FFFFFF;
}

.input-group-inline {
    min-width: 0;
    width: 200px;
    display: inline;
}

.alert {
  margin-bottom: 1px;
  height: 30px;
  line-height: 30px;
  padding: 0px 15px;
}

.alert-message {
    position: relative;
    display: block;
    z-index: 1001;
}
